library(embed)
library(dplyr)
library(testthat)

embed:::is_tf_available()
